#!/bin/bash

#    YAATOBS - yet another avr toolchain build script
# 
#    Copyright (C) 2019  Torsten Brischalle
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/

set -e

. ./00_settings.sh

GCC_FLAGS="--prefix=${TOOLCHAIN_PREFIX} --target=${TOOLCHAIN_TARGET} --enable-languages=c,c++ --disable-nls --disable-libssp --with-dwarf2 --disable-werror"

echo "*****************************************************"
echo "*** build gcc                                     ***"
echo "*****************************************************"

cd tmp

rm -rf gcc-*-build
mkdir gcc-${GCC_VERSION}-build

if [ -d gcc-${GCC_VERSION} ]
then
  echo "gcc already extracted"
else
  if [ -e ../sources/gcc-${GCC_VERSION}.tar.gz ]
  then
    echo "gcc already downloaded"
  else
    echo "download gcc"
    wget ${WGET_OPT} -P ../sources https://ftpmirror.gnu.org/gcc/gcc-${GCC_VERSION}/gcc-${GCC_VERSION}.tar.gz
  fi

  echo "extract gcc"
  tar -xzf ../sources/gcc-${GCC_VERSION}.tar.gz
fi

cd gcc-${GCC_VERSION}-build
echo "configure gcc"
../gcc-${GCC_VERSION}/configure ${GCC_FLAGS}
echo "build gcc"
make
make install

cd ../..

echo "*****************************************************"
echo "*** build gcc: DONE                               ***"
echo "*****************************************************"

