#!/bin/bash

#    YAATOBS - yet another avr toolchain build script
# 
#    Copyright (C) 2019  Torsten Brischalle
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/

set -e

. ./00_settings.sh

AVR_LIBC_FLAGS="--prefix=${TOOLCHAIN_PREFIX} --host=${TOOLCHAIN_TARGET} --disable-werror"

echo "*****************************************************"
echo "*** build avr libc                                ***"
echo "*****************************************************"

cd tmp

if [ -d avr-libc-${AVR_LIBC_VERSION} ]
then
  echo "avr libc already extracted"
else
  if [ -e ../sources/avr-libc-${AVR_LIBC_VERSION}.tar.bz2 ]
  then
    echo "avr libc already downloaded"
  else
    echo "download avr libc"
    wget ${WGET_OPT} -P ../sources http://download.savannah.gnu.org/releases/avr-libc/avr-libc-${AVR_LIBC_VERSION}.tar.bz2
  fi

  echo "extract avr libc"
  tar -xjf ../sources/avr-libc-${AVR_LIBC_VERSION}.tar.bz2
fi

cd avr-libc-${AVR_LIBC_VERSION}
echo "configure avr libc"
./configure ${AVR_LIBC_FLAGS} --build=`./config.guess` 
echo "build avr libc"
make
make install

cd ../..

echo "*****************************************************"
echo "*** build avr libc: DONE                          ***"
echo "*****************************************************"

